quaver documentation
====================

**quaver** is a standalone Python library for quantitative trading signal
generation and walk-forward backtesting.

.. toctree::
   :maxdepth: 2
   :caption: Contents

   getting_started
   strategies/index
   api/index
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
